==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/de/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Massenlöschung von Assets bestätigen',
  'bulk_delete_help'	=> 'Überprüfen Sie die nachfolgenden Assets für die Massenlöschung. Sobald diese gelöscht sind, können diese zwar wiederhergestellt werden, sind aber dem aktuellen Nutzer nicht mehr zugeordnet.',
  'bulk_delete_warn'	=> 'Sie sind im Begriff :asset_count Assets zu löschen.',
	'bulk_update'		=> 'Massenaktualisierung von Assets',
	'bulk_update_help'	=> 'Diese Eingabemaske erlaubt Ihnen die Aktualisierung von mehrere Assets zugleich. Füllen Sie die Felder aus welche Sie ändern möchten. Alle leeren Felder bleiben unverändert. ',
	'bulk_update_warn'	=> 'Sie sind dabei die Eigenschaften von :asset_count Assets zu bearbeiten.',
    'checkedout_to'		=> 'Herausgegeben an',
    'checkout_date'		=> 'Herausgabedatum',
    'checkin_date'		=> 'Rücknahmedatum',
    'checkout_to'		=> 'Herausgeben an',
    'cost'				=> 'Kaufpreis',
    'create'			=> 'Asset erstellen',
    'date'				=> 'Kaufdatum',
    'depreciation'	    => 'Abschreibung',
    'depreciates_on'	=> 'Abschreiben auf',
    'default_location'	=> 'Standard-Standort',
    'eol_date'			=> 'Ende der Nutzungsdauer',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Erwartetes Rückgabedatum',
    'expires'			=> 'Gültig bis',
    'fully_depreciated'	=> 'Komplett Abgeschrieben',
    'help_checkout'		=> 'Um das Asset sofort zuzuweisen, wählen Sie "Bereit zum Herausgeben" in der Status-Liste aus. ',
    'mac_address'		=> 'MAC-Adresse',
    'manufacturer'		=> 'Hersteller',
    'model'				=> 'Modell',
    'months'			=> 'Monate',
    'name'				=> 'Asset Name',
    'notes'				=> 'Notizen',
    'order'				=> 'Auftragsnummer',
    'qr'				=> 'QR-Code',
    'requestable'		=> 'Benutzer dürfen dieses Asset anfordern',
    'select_statustype'	=> 'Status Typ auswählen',
    'serial'			=> 'Seriennummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset ID',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garantie',
		'warranty_expires'		=> 'Garantie Ablaufdatum',
    'years'				=> 'Jahre',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/de/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Massenlöschung von Assets bestätigen',
  'bulk_delete_help'	=> 'Überprüfen Sie die nachfolgenden Assets für die Massenlöschung. Sobald diese gelöscht sind, können diese zwar wiederhergestellt werden, sind aber dem aktuellen Nutzer nicht mehr zugeordnet.',
  'bulk_delete_warn'	=> 'Sie sind im Begriff :asset_count Assets zu löschen.',
    'bulk_update'		=> 'Massenaktualisierung von Assets',
    'bulk_update_help'	=> 'Diese Eingabemaske erlaubt Ihnen die Aktualisierung von mehrere Assets zugleich. Füllen Sie die Felder aus welche Sie ändern möchten. Alle leeren Felder bleiben unverändert. ',
    'bulk_update_warn'	=> 'Sie sind dabei die Eigenschaften von :asset_count Assets zu bearbeiten.',
    'checkedout_to'		=> 'Herausgegeben an',
    'checkout_date'		=> 'Herausgabedatum',
    'checkin_date'		=> 'Rücknahmedatum',
    'checkout_to'		=> 'Herausgeben an',
    'cost'				=> 'Kaufpreis',
    'create'			=> 'Asset erstellen',
    'date'				=> 'Kaufdatum',
    'depreciation'	    => 'Abschreibung',
    'depreciates_on'	=> 'Abschreiben auf',
    'default_location'	=> 'Standard-Standort',
    'eol_date'			=> 'Ende der Nutzungsdauer',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Erwartetes Rückgabedatum',
    'expires'			=> 'Gültig bis',
    'fully_depreciated'	=> 'Komplett Abgeschrieben',
    'help_checkout'		=> 'Um das Asset sofort zuzuweisen, wählen Sie "Bereit zum Herausgeben" in der Status-Liste aus. ',
    'mac_address'		=> 'MAC-Adresse',
    'manufacturer'		=> 'Hersteller',
    'model'				=> 'Modell',
    'months'			=> 'Monate',
    'name'				=> 'Asset Name',
    'notes'				=> 'Notizen',
    'order'				=> 'Auftragsnummer',
    'qr'				=> 'QR-Code',
    'requestable'		=> 'Benutzer dürfen dieses Asset anfordern',
    'select_statustype'	=> 'Status Typ auswählen',
    'serial'			=> 'Seriennummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset ID',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garantie Ablaufdatum',
    'years'				=> 'Jahre',
    'asset_location' => 'Standort des Assets aktualisieren',
    'asset_location_update_default_current' => 'Standardort und aktuellen Standort aktualisieren',
    'asset_location_update_default' => 'Nur den Standardort aktualisieren',
    'asset_not_deployable' => 'Dieses Asset ist nicht verfügbar und kann nicht herausgegeben werden.',
    'asset_deployable' => 'Dieses Asset ist verfügbar und kann herausgegeben werden.',
    'processing_spinner' => 'Wird verarbeitet...',
];
